@@ -3,7 +3,7 @@ from data_engineering_extract_metadata.table_list import get_table_list
 from data_engineering_extract_metadata.utils import (
     write_json,
     read_json,
-    make_folder_if_new,
+    prepare_folder,
 )
 
 
@@ -17,7 +17,7 @@ def create_all_metadata(
     source_folder,
     include_op_column=True,
     include_timestamp_column=True,
-    include_derived_columns=False,
+    include_derived_columns=True,
     include_objects=False,
     filter_function=None,
 ):
@@ -205,7 +205,7 @@ def create_json_for_database(
     -------
     None, but creates a json file in the specified location.
     """
-    make_folder_if_new(location)
+    prepare_folder(location)
 
     db = {
         "description": description,
@@ -265,7 +265,6 @@ def create_json_for_tables(
     None
         But creates a json file for each table in the database.
     """
-    make_folder_if_new(location)
     cursor = connection.cursor()
 
     # Get all the non-nullable columns
@@ -284,6 +283,7 @@ def create_json_for_tables(
             metadata = get_table_meta(
                 cursor,
                 table,
+                schema,
                 not_nullable.get(table.lower(), []),
                 include_op_column,
                 include_timestamp_column,
@@ -312,6 +312,7 @@ def create_json_for_tables(
 def get_table_meta(
     cursor,
     table: str,
+    schema: str,
     not_nullable: list,
     include_op_column: bool = True,
     include_timestamp_column: bool = True,
@@ -366,7 +367,7 @@ def get_table_meta(
         "DB_TYPE_CLOB": "character",
         "DB_TYPE_VARCHAR": "character",
         "DB_TYPE_LONG": "character",
-        "DB_TYPE_RAW": "character",
+        "DB_TYPE_RAW": "binary",
         "DB_TYPE_OBJECT": "array<character>",
     }
     columns = []
@@ -423,14 +424,6 @@ def get_table_meta(
                 }
             )
 
-    document_columns = [
-        {
-            "name": "mojap_document_path",
-            "type": "character",
-            "description": "The path to the document",
-            "nullable": True,
-        }
-    ]
     derived_columns = [
         {
             "name": "mojap_current_record",
@@ -452,27 +445,23 @@ def get_table_meta(
         },
     ]
 
-    # Not yet used - retained from Oasys metadata functions in case it helps later
-    if table == "DOCUMENT_HISTORY":
-        columns += document_columns
-
     if include_derived_columns:
         columns += derived_columns
 
     primary_keys = get_primary_keys(table=table, cursor=cursor)
-    partitions = get_partitions(table=table, cursor=cursor)
+    partition_keys = get_partition_keys(table=table, schema=schema, cursor=cursor)
 
     metadata = {
         "$schema": (
             "https://moj-analytical-services.github.io/metadata_schema/table/"
-            "v1.2.0.json"
+            "v1.4.0.json"
         ),
         "name": table.lower(),
         "description": "",
         "data_format": "parquet",
         "columns": columns,
         "location": f"{table}/",
-        "partitions": partitions,
+        "partitions": partition_keys,
         "primary_key": primary_keys,
     }
     return metadata
@@ -502,54 +491,32 @@ def get_primary_keys(table, cursor):
     return primary_keys
 
 
-def get_partitions(table, cursor):
-    """Extracts partitions and their subpartitions from a table
+def get_partition_keys(schema: str, table: str, cursor) -> list:
+    """Returns a list the partitioning key columns for the given table.
 
-    Run as part of get_curated_metadata
+    Parameters
+    ----------
+    schema : str
+        Also referred to as "owner" in Oracle databases.
+    table : str
+        The table to get partitioning keys for.
+    cursor :
+        A database Cursor object ready to execute queries with.
     """
     statement = (
-        "SELECT partition_name "
-        "FROM ALL_TAB_PARTITIONS "
-        "WHERE table_name = :table_name "
-        "ORDER BY partition_name"
+        "SELECT * "
+        "FROM SYS.all_part_key_columns "
+        "WHERE OWNER = :schema "
+        "AND name = :table_name"
     )
-    cursor.execute(statement, table_name=table)
+    cursor.execute(statement, [schema, table])
     result = cursor.fetchall()
-    if result == []:
-        print(f"No partitions found for table {table.lower()}")
+    if not result:
+        print(f"No partition keys found for table {table.lower()}")
         return None
     else:
-        partitions = [item[0] for item in result]
-        output = []
-        for partition in partitions:
-            subpartitions = get_subpartitions(
-                table=table, partition=partition, cursor=cursor
-            )
-            if subpartitions == []:
-                print(
-                    f"No subpartitions found for partition {partition.lower()} "
-                    f"in table {table.lower()}"
-                )
-                partition_dict = {"name": partition, "subpartitions": None}
-            else:
-                partition_dict = {"name": partition, "subpartitions": subpartitions}
-            output.append(partition_dict)
-        return output
-
-
-def get_subpartitions(table, partition, cursor):
-    """Extracts subpartitions - run as part of get_partitions"""
-    statement = (
-        "SELECT subpartition_name "
-        "FROM ALL_TAB_SUBPARTITIONS "
-        "WHERE table_name = :table_name "
-        "AND partition_name = :partition_name "
-        "ORDER BY subpartition_name"
-    )
-    cursor.execute(statement, table_name=table, partition_name=partition)
-    result = cursor.fetchall()
-    subpartitions = [item[0] for item in result]
-    return subpartitions
+        partition_keys = [item[3].lower() for item in result]
+    return partition_keys
 
 
 def find_not_nullable(cursor, schema):
